==> conventional-changelog-codemirror-4.0.0.tgz: package/README.md <==
# conventional-changelog-codemirror

[![NPM version][npm]][npm-url]
[![Node version][node]][node-url]
[![Dependencies status][deps]][deps-url]
[![Build status][build]][build-url]
[![Coverage status][coverage]][coverage-url]

[npm]: https://img.shields.io/npm/v/conventional-changelog-codemirror.svg
[npm-url]: https://npmjs.com/package/conventional-changelog-codemirror

[node]: https://img.shields.io/node/v/conventional-changelog-codemirror.svg
[node-url]: https://nodejs.org

[deps]: https://img.shields.io/librariesio/release/npm/conventional-changelog-codemirror
[deps-url]: https://libraries.io/npm/conventional-changelog-codemirror/tree

[build]: https://img.shields.io/github/actions/workflow/status/conventional-changelog/conventional-changelog/ci.yaml?branch=master
[build-url]: https://github.com/conventional-changelog/conventional-changelog/actions

[coverage]: https://coveralls.io/repos/github/conventional-changelog/conventional-changelog/badge.svg?branch=master
[coverage-url]: https://coveralls.io/github/conventional-changelog/conventional-changelog?branch=master

[conventional-changelog](https://github.com/conventional-changelog/conventional-changelog) [CodeMirror](https://github.com/codemirror/codemirror) preset.

**Issues with the convention itself should be reported on the CodeMirror issue tracker.**

## Install

```bash
# yarn
yarn add -D conventional-changelog-codemirror
# pnpm
pnpm add -D conventional-changelog-codemirror
# npm
npm i -D conventional-changelog-codemirror
```

==> conventional-changelog-codemirror-5.0.0.tgz: package/README.md <==
# conventional-changelog-codemirror

[![ESM-only package][package]][package-url]
[![NPM version][npm]][npm-url]
[![Node version][node]][node-url]
[![Dependencies status][deps]][deps-url]
[![Install size][size]][size-url]
[![Build status][build]][build-url]
[![Coverage status][coverage]][coverage-url]

[package]: https://img.shields.io/badge/package-ESM--only-ffe536.svg
[package-url]: https://nodejs.org/api/esm.html

[npm]: https://img.shields.io/npm/v/conventional-changelog-codemirror.svg
[npm-url]: https://npmjs.com/package/conventional-changelog-codemirror

[node]: https://img.shields.io/node/v/conventional-changelog-codemirror.svg
[node-url]: https://nodejs.org

[deps]: https://img.shields.io/librariesio/release/npm/conventional-changelog-codemirror
[deps-url]: https://libraries.io/npm/conventional-changelog-codemirror/tree

[size]: https://packagephobia.com/badge?p=conventional-changelog-codemirror
[size-url]: https://packagephobia.com/result?p=conventional-changelog-codemirror

[build]: https://img.shields.io/github/actions/workflow/status/conventional-changelog/conventional-changelog/tests.yaml?branch=master
[build-url]: https://github.com/conventional-changelog/conventional-changelog/actions

[coverage]: https://coveralls.io/repos/github/conventional-changelog/conventional-changelog/badge.svg?branch=master
[coverage-url]: https://coveralls.io/github/conventional-changelog/conventional-changelog?branch=master

[conventional-changelog](https://github.com/conventional-changelog/conventional-changelog) [CodeMirror](https://github.com/codemirror/codemirror) preset.

**Issues with the convention itself should be reported on the CodeMirror issue tracker.**

## Install

```bash
# yarn
yarn add -D conventional-changelog-codemirror
# pnpm
pnpm add -D conventional-changelog-codemirror
# npm
npm i -D conventional-changelog-codemirror
```
